module case3_6(
    input reg [6:0] coeff,
    output reg [8:0] out
); 

/* 
xa + xaxb + xcxd
1 dependent + 1 quad dependent + 1 quad independent
xa + xaxb + xcxd
    Example: 
        Rest + xa + xaxb + xcxd, xa = 1, Rest = 0
        0 + 0*1 + 0*1*xb + 0*xcxd = 0 -> 0 + 0*xb + 0*xcxd = 0 
        0 + 1*1 + 1*1*xb + 1*xcxd = 0 -> 1*1 + 1*xb + 1*xcxd = 0
    "Rest + Coeff1 + Coeff2"
    Solution is [(new eq1, eq2, xa=?),(...)]: [("R1 R2 Coeff1(2) Coeff2(2)", xa), (...)]
*/

always@(*)
begin 
out = 9'b0; 
    case(coeff)
    7'b0000111, 7'b0111000:
        // [(000,111,1),(001,0)]
        begin
            out=9'b000111001;
        end
    7'b0001110, 7'b0110001:
        // [(001,110,1),(010,0)]
        begin
            out=9'b001110010;
        end
    7'b0010101, 7'b0101010:
        // [(010,101,1),(001,0)]
        begin
            out=9'b010101001;
        end
    7'b0011100, 7'b0100011:
        // [(011,100,1),(010,0)]
        begin
            out=9'b011100010;
        end
    7'b1000111, 7'b1111000:
        // [(100,011,1),(100,011,0)]
        begin
            out=9'b100011000;
        end
    7'b1001110, 7'b1110001:
        // zero padded 
        // [(101,010,1),(101,010,0)]
        begin
            out=9'b101010000;
        end
    7'b1010101, 7'b1101010:
        // [(110,001,1),(110,001,0)]
        begin
            out=9'b110001000;
        end
    7'b1011100, 7'b1100011:
        // [(111,000,1),(111,000,0)] ? 
        begin
            out=9'b111000000;
        end
    endcase
end 
endmodule